# pylzstring
[![Build Status](https://github.com/johndoe31415/pylzstring/actions/workflows/CI.yml/badge.svg)](https://github.com/johndoe31415/pylzstring/actions/workflows/CI.yml)

This is a native Python3.10+ lzstring decompression library. It compresses only
bytestrings (i.e., does not make use of word-sized symbols during compression).

## License
GNU GPL-3.
